# Interfacing heron and bilby

The scripts and notebooks in this directory are designed for developing the interface between heron and bilby,
so that heron can be used as a waveform model for inference.
